summaryrefslogtreecommitdiffstats
path: root/Tools/cases_generator/analysis.py
diff options
context:
space:
mode:
Diffstat (limited to 'Tools/cases_generator/analysis.py')
-rw-r--r--Tools/cases_generator/analysis.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Tools/cases_generator/analysis.py b/Tools/cases_generator/analysis.py
index 7c7c908..9e0124b 100644
--- a/Tools/cases_generator/analysis.py
+++ b/Tools/cases_generator/analysis.py
@@ -365,8 +365,8 @@ class Analyzer:
case Instruction() as instr:
part, offset = self.analyze_instruction(instr, offset)
parts.append(part)
- if instr.name != "SAVE_IP":
- # SAVE_IP in a macro is a no-op in Tier 1
+ if instr.name != "_SET_IP":
+ # _SET_IP in a macro is a no-op in Tier 1
flags.add(instr.instr_flags)
case _:
assert_never(component)